.. pys5p documentation master file, created by
   sphinx-quickstart on Fri Sep 30 11:35:47 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Package pyS5p User Manual
==========================

pyS5p provides a Python interface to S5p Tropomi Level-1B (and 2) products.

For more information on the Sentinel 5 precursor mission visit:

* https://earth.esa.int/web/guest/missions/esa-future-missions/sentinel-5P
* http://www.tropomi.eu

For more information on the Tropomi Level-1B products visit:

* http://www.tropomi.eu/documents/level-0-1b-products


Quick-start
-----------

.. toctree::
    :maxdepth: 1

    quick
    build


Module Documentation
--------------------

.. toctree::
   :maxdepth: 2

   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
